==> jc-1.4.0.tar.gz: gnu/regexp/UncheckedRE.h <==
// public final class gnu.regexp.UncheckedRE

// class file dependencies
// @dep_class aa2ce6e36aa0b12a gnu_regexp_RE
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 6649e3dbf5772d58 gnu_regexp_UncheckedRE
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_RE

#include "gnu/regexp/RE.h"

#ifndef _JC_gnu_regexp_UncheckedRE_H_
#define _JC_gnu_regexp_UncheckedRE_H_

// Forward structure declarations
struct _jc_gnu_regexp_RESyntax$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_regexp_UncheckedRE$sub_refs	_jc_gnu_regexp_UncheckedRE$sub_refs;
typedef struct _jc_gnu_regexp_UncheckedRE$sub_nonrefs	_jc_gnu_regexp_UncheckedRE$sub_nonrefs;
typedef struct _jc_gnu_regexp_UncheckedRE$refs	_jc_gnu_regexp_UncheckedRE$refs;
typedef struct _jc_gnu_regexp_UncheckedRE$nonrefs	_jc_gnu_regexp_UncheckedRE$nonrefs;
typedef struct _jc_gnu_regexp_UncheckedRE$object	_jc_gnu_regexp_UncheckedRE$object;

typedef const struct _jc_gnu_regexp_UncheckedRE$vmethods	_jc_gnu_regexp_UncheckedRE$vmethods;
typedef const struct _jc_gnu_regexp_UncheckedRE$vtable	_jc_gnu_regexp_UncheckedRE$vtable;
typedef const struct _jc_gnu_regexp_UncheckedRE$vtype	_jc_gnu_regexp_UncheckedRE$vtype;

// Constructors
extern void _jc_gnu_regexp_UncheckedRE$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_regexp_UncheckedRE$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *, jint);
extern void _jc_gnu_regexp_UncheckedRE$method$_init$0f25469c0bcb1de7(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_gnu_regexp_RESyntax$object *);

// Virtual methods structure
struct _jc_gnu_regexp_UncheckedRE$vmethods {
};

// Vtable
struct _jc_gnu_regexp_UncheckedRE$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RE$vmethods	gnu_regexp_RE;
	_jc_gnu_regexp_UncheckedRE$vmethods	gnu_regexp_UncheckedRE;
};

// Vtype
struct _jc_gnu_regexp_UncheckedRE$vtype {
	_jc_type			type;
	_jc_gnu_regexp_UncheckedRE$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_UncheckedRE$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_UncheckedRE$refs {
    _jc_gnu_regexp_UncheckedRE$sub_refs	gnu_regexp_UncheckedRE;
    _jc_gnu_regexp_RE$sub_refs	gnu_regexp_RE;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_UncheckedRE$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_UncheckedRE$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RE$sub_nonrefs	gnu_regexp_RE;
    _jc_gnu_regexp_UncheckedRE$sub_nonrefs	gnu_regexp_UncheckedRE;
};

// Object instance structure
struct _jc_gnu_regexp_UncheckedRE$object {
	_jc_gnu_regexp_UncheckedRE$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_UncheckedRE$vtype	*vtype;
	_jc_gnu_regexp_UncheckedRE$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_UncheckedRE$vtype _jc_gnu_regexp_UncheckedRE$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_UncheckedRE, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_UncheckedRE$class_object;

#endif	/* _JC_gnu_regexp_UncheckedRE_H_ */

==> jc-1.4.5.tar.gz: gnu/regexp/UncheckedRE.h <==
// public final class gnu.regexp.UncheckedRE

// class file dependencies
// @dep_class aa2ce6e36aa0b12a gnu_regexp_RE
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 6649e3dbf5772d58 gnu_regexp_UncheckedRE
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_RE

#include "gnu/regexp/RE.h"

#ifndef _JC_gnu_regexp_UncheckedRE_H_
#define _JC_gnu_regexp_UncheckedRE_H_

// Forward structure declarations
struct _jc_gnu_regexp_RESyntax$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_regexp_UncheckedRE$sub_refs	_jc_gnu_regexp_UncheckedRE$sub_refs;
typedef struct _jc_gnu_regexp_UncheckedRE$sub_nonrefs	_jc_gnu_regexp_UncheckedRE$sub_nonrefs;
typedef struct _jc_gnu_regexp_UncheckedRE$refs	_jc_gnu_regexp_UncheckedRE$refs;
typedef struct _jc_gnu_regexp_UncheckedRE$nonrefs	_jc_gnu_regexp_UncheckedRE$nonrefs;
typedef struct _jc_gnu_regexp_UncheckedRE$object	_jc_gnu_regexp_UncheckedRE$object;

typedef const struct _jc_gnu_regexp_UncheckedRE$vmethods	_jc_gnu_regexp_UncheckedRE$vmethods;
typedef const struct _jc_gnu_regexp_UncheckedRE$vtable	_jc_gnu_regexp_UncheckedRE$vtable;
typedef const struct _jc_gnu_regexp_UncheckedRE$vtype	_jc_gnu_regexp_UncheckedRE$vtype;

// Constructors
extern void _jc_gnu_regexp_UncheckedRE$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_UncheckedRE$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_UncheckedRE$method$_init$0f25469c0bcb1de7(_jc_env *, struct _jc_gnu_regexp_UncheckedRE$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_regexp_UncheckedRE$vmethods {
};

// Vtable
struct _jc_gnu_regexp_UncheckedRE$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RE$vmethods	gnu_regexp_RE;
	_jc_gnu_regexp_UncheckedRE$vmethods	gnu_regexp_UncheckedRE;
};

// Vtype
struct _jc_gnu_regexp_UncheckedRE$vtype {
	_jc_type			type;
	_jc_gnu_regexp_UncheckedRE$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_UncheckedRE$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_UncheckedRE$refs {
    _jc_gnu_regexp_UncheckedRE$sub_refs	gnu_regexp_UncheckedRE;
    _jc_gnu_regexp_RE$sub_refs	gnu_regexp_RE;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_UncheckedRE$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_UncheckedRE$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RE$sub_nonrefs	gnu_regexp_RE;
    _jc_gnu_regexp_UncheckedRE$sub_nonrefs	gnu_regexp_UncheckedRE;
};

// Object instance structure
struct _jc_gnu_regexp_UncheckedRE$object {
	_jc_gnu_regexp_UncheckedRE$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_UncheckedRE$vtype	*vtype;
	_jc_gnu_regexp_UncheckedRE$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_UncheckedRE$vtype _jc_gnu_regexp_UncheckedRE$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_UncheckedRE, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_UncheckedRE$class_object;

#endif	/* _JC_gnu_regexp_UncheckedRE_H_ */
